AntplusLogData class

Constructors

AntplusLogData({required AntplusLogEvent level, required String tag, required String message})

Properties

hashCode int
The hash code for this object.
no setteroverride
level AntplusLogEvent
getter/setter pair
message String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) AntplusLogData